twutils - Python tools for turboWAVE PIC code
=============================================

Modules
-------

#. twutils.NLO: evaluate dispersion in explicit nonlinear optics model
#. twutils.plot: Prepare inputs for matplotlib/mayavi based on data in npy files
#. twutils.pre: Conversion between experimental and simulation parameters
#. twutils.QO.stationary: Stationary states of quantum mechanical wave equations
#. twutils.QO.ionization: Ionization potentials, rates, and units

Scripts
-------

#. twplot: command line plotter
#. wigner: command line plotter for Wigner distributions
#. twtest: script to run a test suite
#. os2tw: script to convert OSIRIS outputs to turboWAVE outputs
